# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._createable_api_resource import CreateableAPIResource
from stripe._deletable_api_resource import DeletableAPIResource
from stripe._expandable_field import ExpandableField
from stripe._list_object import ListObject
from stripe._listable_api_resource import ListableAPIResource
from stripe._stripe_object import StripeObject, UntypedStripeObject
from stripe._updateable_api_resource import UpdateableAPIResource
from stripe._util import class_method_variant, sanitize_id
from typing import ClassVar, List, Optional, cast, overload
from typing_extensions import Literal, Unpack, TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._discount import Discount
    from stripe._plan import Plan
    from stripe._price import Price
    from stripe._tax_rate import TaxRate
    from stripe.params._subscription_item_create_params import (
        SubscriptionItemCreateParams,
    )
    from stripe.params._subscription_item_delete_params import (
        SubscriptionItemDeleteParams,
    )
    from stripe.params._subscription_item_list_params import (
        SubscriptionItemListParams,
    )
    from stripe.params._subscription_item_modify_params import (
        SubscriptionItemModifyParams,
    )
    from stripe.params._subscription_item_retrieve_params import (
        SubscriptionItemRetrieveParams,
    )


class SubscriptionItem(
    CreateableAPIResource["SubscriptionItem"],
    DeletableAPIResource["SubscriptionItem"],
    ListableAPIResource["SubscriptionItem"],
    UpdateableAPIResource["SubscriptionItem"],
):
    """
    Subscription items allow you to create customer subscriptions with more than
    one plan, making it easy to represent complex billing relationships.
    """

    OBJECT_NAME: ClassVar[Literal["subscription_item"]] = "subscription_item"

    class BillingThresholds(StripeObject):
        usage_gte: Optional[int]
        """
        Usage threshold that triggers the subscription to create an invoice
        """

    billed_until: Optional[int]
    """
    The time period the subscription item has been billed for.
    """
    billing_thresholds: Optional[BillingThresholds]
    """
    Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period
    """
    created: int
    """
    Time at which the object was created. Measured in seconds since the Unix epoch.
    """
    current_period_end: int
    """
    The end time of this subscription item's current billing period.
    """
    current_period_start: int
    """
    The start time of this subscription item's current billing period.
    """
    deleted: Optional[Literal[True]]
    """
    Always true for a deleted object
    """
    discounts: List[ExpandableField["Discount"]]
    """
    The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use `expand[]=discounts` to expand each discount.
    """
    id: str
    """
    Unique identifier for the object.
    """
    metadata: UntypedStripeObject[str]
    """
    Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
    """
    object: Literal["subscription_item"]
    """
    String representing the object's type. Objects of the same type share the same value.
    """
    plan: "Plan"
    """
    You can now model subscriptions more flexibly using the [Prices API](https://api.stripe.com#prices). It replaces the Plans API and is backwards compatible to simplify your migration.

    Plans define the base price, currency, and billing cycle for recurring purchases of products.
    [Products](https://api.stripe.com#products) help you track inventory or provisioning, and plans help you track pricing. Different physical goods or levels of service should be represented by products, and pricing options should be represented by plans. This approach lets you change prices without having to change your provisioning scheme.

    For example, you might have a single "gold" product that has plans for $10/month, $100/year, €9/month, and €90/year.

    Related guides: [Set up a subscription](https://docs.stripe.com/billing/subscriptions/set-up-subscription) and more about [products and prices](https://docs.stripe.com/products-prices/overview).
    """
    price: "Price"
    """
    Prices define the unit cost, currency, and (optional) billing cycle for both recurring and one-time purchases of products.
    [Products](https://api.stripe.com#products) help you track inventory or provisioning, and prices help you track payment terms. Different physical goods or levels of service should be represented by products, and pricing options should be represented by prices. This approach lets you change prices without having to change your provisioning scheme.

    For example, you might have a single "gold" product that has prices for $10/month, $100/year, and €9 once.

    Related guides: [Set up a subscription](https://docs.stripe.com/billing/subscriptions/set-up-subscription), [create an invoice](https://docs.stripe.com/billing/invoices/create), and more about [products and prices](https://docs.stripe.com/products-prices/overview).
    """
    quantity: Optional[int]
    """
    The [quantity](https://docs.stripe.com/subscriptions/quantities) of the plan to which the customer should be subscribed.
    """
    subscription: str
    """
    The `subscription` this `subscription_item` belongs to.
    """
    tax_rates: Optional[List["TaxRate"]]
    """
    The tax rates which apply to this `subscription_item`. When set, the `default_tax_rates` on the subscription do not apply to this `subscription_item`.
    """

    @classmethod
    def create(
        cls, **params: Unpack["SubscriptionItemCreateParams"]
    ) -> "SubscriptionItem":
        """
        Adds a new item to an existing subscription. No existing items will be changed or replaced.
        """
        return cast(
            "SubscriptionItem",
            cls._static_request(
                "post",
                cls.class_url(),
                params=params,
            ),
        )

    @classmethod
    async def create_async(
        cls, **params: Unpack["SubscriptionItemCreateParams"]
    ) -> "SubscriptionItem":
        """
        Adds a new item to an existing subscription. No existing items will be changed or replaced.
        """
        return cast(
            "SubscriptionItem",
            await cls._static_request_async(
                "post",
                cls.class_url(),
                params=params,
            ),
        )

    @classmethod
    def _cls_delete(
        cls, sid: str, **params: Unpack["SubscriptionItemDeleteParams"]
    ) -> "SubscriptionItem":
        """
        Deletes an item from the subscription. Removing a subscription item from a subscription will not cancel the subscription.
        """
        url = "%s/%s" % (cls.class_url(), sanitize_id(sid))
        return cast(
            "SubscriptionItem",
            cls._static_request(
                "delete",
                url,
                params=params,
            ),
        )

    @overload
    @staticmethod
    def delete(
        sid: str, **params: Unpack["SubscriptionItemDeleteParams"]
    ) -> "SubscriptionItem":
        """
        Deletes an item from the subscription. Removing a subscription item from a subscription will not cancel the subscription.
        """
        ...

    @overload
    def delete(
        self, **params: Unpack["SubscriptionItemDeleteParams"]
    ) -> "SubscriptionItem":
        """
        Deletes an item from the subscription. Removing a subscription item from a subscription will not cancel the subscription.
        """
        ...

    @class_method_variant("_cls_delete")
    def delete(  # pyright: ignore[reportGeneralTypeIssues]
        self, **params: Unpack["SubscriptionItemDeleteParams"]
    ) -> "SubscriptionItem":
        """
        Deletes an item from the subscription. Removing a subscription item from a subscription will not cancel the subscription.
        """
        return self._request_and_refresh(
            "delete",
            self.instance_url(),
            params=params,
        )

    @classmethod
    async def _cls_delete_async(
        cls, sid: str, **params: Unpack["SubscriptionItemDeleteParams"]
    ) -> "SubscriptionItem":
        """
        Deletes an item from the subscription. Removing a subscription item from a subscription will not cancel the subscription.
        """
        url = "%s/%s" % (cls.class_url(), sanitize_id(sid))
        return cast(
            "SubscriptionItem",
            await cls._static_request_async(
                "delete",
                url,
                params=params,
            ),
        )

    @overload
    @staticmethod
    async def delete_async(
        sid: str, **params: Unpack["SubscriptionItemDeleteParams"]
    ) -> "SubscriptionItem":
        """
        Deletes an item from the subscription. Removing a subscription item from a subscription will not cancel the subscription.
        """
        ...

    @overload
    async def delete_async(
        self, **params: Unpack["SubscriptionItemDeleteParams"]
    ) -> "SubscriptionItem":
        """
        Deletes an item from the subscription. Removing a subscription item from a subscription will not cancel the subscription.
        """
        ...

    @class_method_variant("_cls_delete_async")
    async def delete_async(  # pyright: ignore[reportGeneralTypeIssues]
        self, **params: Unpack["SubscriptionItemDeleteParams"]
    ) -> "SubscriptionItem":
        """
        Deletes an item from the subscription. Removing a subscription item from a subscription will not cancel the subscription.
        """
        return await self._request_and_refresh_async(
            "delete",
            self.instance_url(),
            params=params,
        )

    @classmethod
    def list(
        cls, **params: Unpack["SubscriptionItemListParams"]
    ) -> ListObject["SubscriptionItem"]:
        """
        Returns a list of your subscription items for a given subscription.
        """
        result = cls._static_request(
            "get",
            cls.class_url(),
            params=params,
        )
        if not isinstance(result, ListObject):
            raise TypeError(
                "Expected list object from API, got %s"
                % (type(result).__name__)
            )

        return result

    @classmethod
    async def list_async(
        cls, **params: Unpack["SubscriptionItemListParams"]
    ) -> ListObject["SubscriptionItem"]:
        """
        Returns a list of your subscription items for a given subscription.
        """
        result = await cls._static_request_async(
            "get",
            cls.class_url(),
            params=params,
        )
        if not isinstance(result, ListObject):
            raise TypeError(
                "Expected list object from API, got %s"
                % (type(result).__name__)
            )

        return result

    @classmethod
    def modify(
        cls, id: str, **params: Unpack["SubscriptionItemModifyParams"]
    ) -> "SubscriptionItem":
        """
        Updates the plan or quantity of an item on a current subscription.
        """
        url = "%s/%s" % (cls.class_url(), sanitize_id(id))
        return cast(
            "SubscriptionItem",
            cls._static_request(
                "post",
                url,
                params=params,
            ),
        )

    @classmethod
    async def modify_async(
        cls, id: str, **params: Unpack["SubscriptionItemModifyParams"]
    ) -> "SubscriptionItem":
        """
        Updates the plan or quantity of an item on a current subscription.
        """
        url = "%s/%s" % (cls.class_url(), sanitize_id(id))
        return cast(
            "SubscriptionItem",
            await cls._static_request_async(
                "post",
                url,
                params=params,
            ),
        )

    @classmethod
    def retrieve(
        cls, id: str, **params: Unpack["SubscriptionItemRetrieveParams"]
    ) -> "SubscriptionItem":
        """
        Retrieves the subscription item with the given ID.
        """
        instance = cls(id, **params)
        instance.refresh()
        return instance

    @classmethod
    async def retrieve_async(
        cls, id: str, **params: Unpack["SubscriptionItemRetrieveParams"]
    ) -> "SubscriptionItem":
        """
        Retrieves the subscription item with the given ID.
        """
        instance = cls(id, **params)
        await instance.refresh_async()
        return instance

    _inner_class_types = {"billing_thresholds": BillingThresholds}



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import List, Union
from typing_extensions import Literal, NotRequired, TypedDict


class OutboundTransferUpdateParams(TypedDict):
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    tracking_details: "OutboundTransferUpdateParamsTrackingDetails"
    """
    Details about network-specific tracking information.
    """


class OutboundTransferUpdateParamsTrackingDetails(TypedDict):
    ach: NotRequired["OutboundTransferUpdateParamsTrackingDetailsAch"]
    """
    ACH network tracking details.
    """
    type: Union[Literal["ach", "us_domestic_wire"], str]
    """
    The US bank account network used to send funds.
    """
    us_domestic_wire: NotRequired[
        "OutboundTransferUpdateParamsTrackingDetailsUsDomesticWire"
    ]
    """
    US domestic wire network tracking details.
    """


class OutboundTransferUpdateParamsTrackingDetailsAch(TypedDict):
    trace_id: str
    """
    ACH trace ID for funds sent over the `ach` network.
    """


class OutboundTransferUpdateParamsTrackingDetailsUsDomesticWire(TypedDict):
    chips: NotRequired[str]
    """
    CHIPS System Sequence Number (SSN) for funds sent over the `us_domestic_wire` network.
    """
    imad: NotRequired[str]
    """
    IMAD for funds sent over the `us_domestic_wire` network.
    """
    omad: NotRequired[str]
    """
    OMAD for funds sent over the `us_domestic_wire` network.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import List
from typing_extensions import NotRequired


class ValueListItemCreateParams(RequestOptions):
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    value: str
    """
    The value of the item (whose type must match the type of the parent value list).
    """
    value_list: str
    """
    The identifier of the value list which the created item will be added to.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.v2.core import accounts as accounts
    from stripe.params.v2.core._account_close_params import (
        AccountCloseParams as AccountCloseParams,
    )
    from stripe.params.v2.core._account_create_params import (
        AccountCreateParams as AccountCreateParams,
        AccountCreateParamsConfiguration as AccountCreateParamsConfiguration,
        AccountCreateParamsConfigurationCustomer as AccountCreateParamsConfigurationCustomer,
        AccountCreateParamsConfigurationCustomerAutomaticIndirectTax as AccountCreateParamsConfigurationCustomerAutomaticIndirectTax,
        AccountCreateParamsConfigurationCustomerBilling as AccountCreateParamsConfigurationCustomerBilling,
        AccountCreateParamsConfigurationCustomerBillingInvoice as AccountCreateParamsConfigurationCustomerBillingInvoice,
        AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField as AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField,
        AccountCreateParamsConfigurationCustomerBillingInvoiceRendering as AccountCreateParamsConfigurationCustomerBillingInvoiceRendering,
        AccountCreateParamsConfigurationCustomerCapabilities as AccountCreateParamsConfigurationCustomerCapabilities,
        AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax as AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax,
        AccountCreateParamsConfigurationCustomerShipping as AccountCreateParamsConfigurationCustomerShipping,
        AccountCreateParamsConfigurationCustomerShippingAddress as AccountCreateParamsConfigurationCustomerShippingAddress,
        AccountCreateParamsConfigurationMerchant as AccountCreateParamsConfigurationMerchant,
        AccountCreateParamsConfigurationMerchantBacsDebitPayments as AccountCreateParamsConfigurationMerchantBacsDebitPayments,
        AccountCreateParamsConfigurationMerchantBranding as AccountCreateParamsConfigurationMerchantBranding,
        AccountCreateParamsConfigurationMerchantCapabilities as AccountCreateParamsConfigurationMerchantCapabilities,
        AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments as AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments as AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments as AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments as AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments as AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments as AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments as AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments as AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments,
        AccountCreateParamsConfigurationMerchantCardPayments as AccountCreateParamsConfigurationMerchantCardPayments,
        AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn as AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn,
        AccountCreateParamsConfigurationMerchantKonbiniPayments as AccountCreateParamsConfigurationMerchantKonbiniPayments,
        AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupport as AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupport,
        AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupportHours as AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupportHours,
        AccountCreateParamsConfigurationMerchantScriptStatementDescriptor as AccountCreateParamsConfigurationMerchantScriptStatementDescriptor,
        AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKana as AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKana,
        AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKanji as AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKanji,
        AccountCreateParamsConfigurationMerchantStatementDescriptor as AccountCreateParamsConfigurationMerchantStatementDescriptor,
        AccountCreateParamsConfigurationMerchantSupport as AccountCreateParamsConfigurationMerchantSupport,
        AccountCreateParamsConfigurationMerchantSupportAddress as AccountCreateParamsConfigurationMerchantSupportAddress,
        AccountCreateParamsConfigurationRecipient as AccountCreateParamsConfigurationRecipient,
        AccountCreateParamsConfigurationRecipientCapabilities as AccountCreateParamsConfigurationRecipientCapabilities,
        AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance as AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance,
        AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers as AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers,
        AccountCreateParamsDefaults as AccountCreateParamsDefaults,
        AccountCreateParamsDefaultsProfile as AccountCreateParamsDefaultsProfile,
        AccountCreateParamsDefaultsResponsibilities as AccountCreateParamsDefaultsResponsibilities,
        AccountCreateParamsIdentity as AccountCreateParamsIdentity,
        AccountCreateParamsIdentityAttestations as AccountCreateParamsIdentityAttestations,
        AccountCreateParamsIdentityAttestationsDirectorshipDeclaration as AccountCreateParamsIdentityAttestationsDirectorshipDeclaration,
        AccountCreateParamsIdentityAttestationsOwnershipDeclaration as AccountCreateParamsIdentityAttestationsOwnershipDeclaration,
        AccountCreateParamsIdentityAttestationsPersonsProvided as AccountCreateParamsIdentityAttestationsPersonsProvided,
        AccountCreateParamsIdentityAttestationsRepresentativeDeclaration as AccountCreateParamsIdentityAttestationsRepresentativeDeclaration,
        AccountCreateParamsIdentityAttestationsTermsOfService as AccountCreateParamsIdentityAttestationsTermsOfService,
        AccountCreateParamsIdentityAttestationsTermsOfServiceAccount as AccountCreateParamsIdentityAttestationsTermsOfServiceAccount,
        AccountCreateParamsIdentityBusinessDetails as AccountCreateParamsIdentityBusinessDetails,
        AccountCreateParamsIdentityBusinessDetailsAdditionalAddress as AccountCreateParamsIdentityBusinessDetailsAdditionalAddress,
        AccountCreateParamsIdentityBusinessDetailsAddress as AccountCreateParamsIdentityBusinessDetailsAddress,
        AccountCreateParamsIdentityBusinessDetailsAnnualRevenue as AccountCreateParamsIdentityBusinessDetailsAnnualRevenue,
        AccountCreateParamsIdentityBusinessDetailsDocuments as AccountCreateParamsIdentityBusinessDetailsDocuments,
        AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner,
        AccountCreateParamsIdentityBusinessDetailsIdNumber as AccountCreateParamsIdentityBusinessDetailsIdNumber,
        AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
        AccountCreateParamsIdentityBusinessDetailsRegistrationDate as AccountCreateParamsIdentityBusinessDetailsRegistrationDate,
        AccountCreateParamsIdentityBusinessDetailsScriptAddresses as AccountCreateParamsIdentityBusinessDetailsScriptAddresses,
        AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana as AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana,
        AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji,
        AccountCreateParamsIdentityBusinessDetailsScriptNames as AccountCreateParamsIdentityBusinessDetailsScriptNames,
        AccountCreateParamsIdentityBusinessDetailsScriptNamesKana as AccountCreateParamsIdentityBusinessDetailsScriptNamesKana,
        AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji as AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji,
        AccountCreateParamsIdentityIndividual as AccountCreateParamsIdentityIndividual,
        AccountCreateParamsIdentityIndividualAdditionalAddress as AccountCreateParamsIdentityIndividualAdditionalAddress,
        AccountCreateParamsIdentityIndividualAdditionalName as AccountCreateParamsIdentityIndividualAdditionalName,
        AccountCreateParamsIdentityIndividualAddress as AccountCreateParamsIdentityIndividualAddress,
        AccountCreateParamsIdentityIndividualDateOfBirth as AccountCreateParamsIdentityIndividualDateOfBirth,
        AccountCreateParamsIdentityIndividualDocuments as AccountCreateParamsIdentityIndividualDocuments,
        AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization,
        AccountCreateParamsIdentityIndividualDocumentsPassport as AccountCreateParamsIdentityIndividualDocumentsPassport,
        AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification as AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification,
        AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
        AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification as AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification,
        AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
        AccountCreateParamsIdentityIndividualDocumentsVisa as AccountCreateParamsIdentityIndividualDocumentsVisa,
        AccountCreateParamsIdentityIndividualIdNumber as AccountCreateParamsIdentityIndividualIdNumber,
        AccountCreateParamsIdentityIndividualRelationship as AccountCreateParamsIdentityIndividualRelationship,
        AccountCreateParamsIdentityIndividualScriptAddresses as AccountCreateParamsIdentityIndividualScriptAddresses,
        AccountCreateParamsIdentityIndividualScriptAddressesKana as AccountCreateParamsIdentityIndividualScriptAddressesKana,
        AccountCreateParamsIdentityIndividualScriptAddressesKanji as AccountCreateParamsIdentityIndividualScriptAddressesKanji,
        AccountCreateParamsIdentityIndividualScriptNames as AccountCreateParamsIdentityIndividualScriptNames,
        AccountCreateParamsIdentityIndividualScriptNamesKana as AccountCreateParamsIdentityIndividualScriptNamesKana,
        AccountCreateParamsIdentityIndividualScriptNamesKanji as AccountCreateParamsIdentityIndividualScriptNamesKanji,
    )
    from stripe.params.v2.core._account_link_create_params import (
        AccountLinkCreateParams as AccountLinkCreateParams,
        AccountLinkCreateParamsUseCase as AccountLinkCreateParamsUseCase,
        AccountLinkCreateParamsUseCaseAccountOnboarding as AccountLinkCreateParamsUseCaseAccountOnboarding,
        AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions as AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions,
        AccountLinkCreateParamsUseCaseAccountUpdate as AccountLinkCreateParamsUseCaseAccountUpdate,
        AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions as AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions,
    )
    from stripe.params.v2.core._account_list_params import (
        AccountListParams as AccountListParams,
    )
    from stripe.params.v2.core._account_retrieve_params import (
        AccountRetrieveParams as AccountRetrieveParams,
    )
    from stripe.params.v2.core._account_token_create_params import (
        AccountTokenCreateParams as AccountTokenCreateParams,
        AccountTokenCreateParamsIdentity as AccountTokenCreateParamsIdentity,
        AccountTokenCreateParamsIdentityAttestations as AccountTokenCreateParamsIdentityAttestations,
        AccountTokenCreateParamsIdentityAttestationsDirectorshipDeclaration as AccountTokenCreateParamsIdentityAttestationsDirectorshipDeclaration,
        AccountTokenCreateParamsIdentityAttestationsOwnershipDeclaration as AccountTokenCreateParamsIdentityAttestationsOwnershipDeclaration,
        AccountTokenCreateParamsIdentityAttestationsPersonsProvided as AccountTokenCreateParamsIdentityAttestationsPersonsProvided,
        AccountTokenCreateParamsIdentityAttestationsRepresentativeDeclaration as AccountTokenCreateParamsIdentityAttestationsRepresentativeDeclaration,
        AccountTokenCreateParamsIdentityAttestationsTermsOfService as AccountTokenCreateParamsIdentityAttestationsTermsOfService,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceAccount as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceAccount,
        AccountTokenCreateParamsIdentityBusinessDetails as AccountTokenCreateParamsIdentityBusinessDetails,
        AccountTokenCreateParamsIdentityBusinessDetailsAdditionalAddress as AccountTokenCreateParamsIdentityBusinessDetailsAdditionalAddress,
        AccountTokenCreateParamsIdentityBusinessDetailsAddress as AccountTokenCreateParamsIdentityBusinessDetailsAddress,
        AccountTokenCreateParamsIdentityBusinessDetailsAnnualRevenue as AccountTokenCreateParamsIdentityBusinessDetailsAnnualRevenue,
        AccountTokenCreateParamsIdentityBusinessDetailsDocuments as AccountTokenCreateParamsIdentityBusinessDetailsDocuments,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner,
        AccountTokenCreateParamsIdentityBusinessDetailsIdNumber as AccountTokenCreateParamsIdentityBusinessDetailsIdNumber,
        AccountTokenCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountTokenCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
        AccountTokenCreateParamsIdentityBusinessDetailsRegistrationDate as AccountTokenCreateParamsIdentityBusinessDetailsRegistrationDate,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptAddresses as AccountTokenCreateParamsIdentityBusinessDetailsScriptAddresses,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKana as AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKana,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKanji,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptNames as AccountTokenCreateParamsIdentityBusinessDetailsScriptNames,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKana as AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKana,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKanji as AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKanji,
        AccountTokenCreateParamsIdentityIndividual as AccountTokenCreateParamsIdentityIndividual,
        AccountTokenCreateParamsIdentityIndividualAdditionalAddress as AccountTokenCreateParamsIdentityIndividualAdditionalAddress,
        AccountTokenCreateParamsIdentityIndividualAdditionalName as AccountTokenCreateParamsIdentityIndividualAdditionalName,
        AccountTokenCreateParamsIdentityIndividualAddress as AccountTokenCreateParamsIdentityIndividualAddress,
        AccountTokenCreateParamsIdentityIndividualDateOfBirth as AccountTokenCreateParamsIdentityIndividualDateOfBirth,
        AccountTokenCreateParamsIdentityIndividualDocuments as AccountTokenCreateParamsIdentityIndividualDocuments,
        AccountTokenCreateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountTokenCreateParamsIdentityIndividualDocumentsCompanyAuthorization,
        AccountTokenCreateParamsIdentityIndividualDocumentsPassport as AccountTokenCreateParamsIdentityIndividualDocumentsPassport,
        AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerification as AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerification,
        AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
        AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerification as AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerification,
        AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
        AccountTokenCreateParamsIdentityIndividualDocumentsVisa as AccountTokenCreateParamsIdentityIndividualDocumentsVisa,
        AccountTokenCreateParamsIdentityIndividualIdNumber as AccountTokenCreateParamsIdentityIndividualIdNumber,
        AccountTokenCreateParamsIdentityIndividualRelationship as AccountTokenCreateParamsIdentityIndividualRelationship,
        AccountTokenCreateParamsIdentityIndividualScriptAddresses as AccountTokenCreateParamsIdentityIndividualScriptAddresses,
        AccountTokenCreateParamsIdentityIndividualScriptAddressesKana as AccountTokenCreateParamsIdentityIndividualScriptAddressesKana,
        AccountTokenCreateParamsIdentityIndividualScriptAddressesKanji as AccountTokenCreateParamsIdentityIndividualScriptAddressesKanji,
        AccountTokenCreateParamsIdentityIndividualScriptNames as AccountTokenCreateParamsIdentityIndividualScriptNames,
        AccountTokenCreateParamsIdentityIndividualScriptNamesKana as AccountTokenCreateParamsIdentityIndividualScriptNamesKana,
        AccountTokenCreateParamsIdentityIndividualScriptNamesKanji as AccountTokenCreateParamsIdentityIndividualScriptNamesKanji,
    )
    from stripe.params.v2.core._account_token_retrieve_params import (
        AccountTokenRetrieveParams as AccountTokenRetrieveParams,
    )
    from stripe.params.v2.core._account_update_params import (
        AccountUpdateParams as AccountUpdateParams,
        AccountUpdateParamsConfiguration as AccountUpdateParamsConfiguration,
        AccountUpdateParamsConfigurationCustomer as AccountUpdateParamsConfigurationCustomer,
        AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax as AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax,
        AccountUpdateParamsConfigurationCustomerBilling as AccountUpdateParamsConfigurationCustomerBilling,
        AccountUpdateParamsConfigurationCustomerBillingInvoice as AccountUpdateParamsConfigurationCustomerBillingInvoice,
        AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField as AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField,
        AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering as AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering,
        AccountUpdateParamsConfigurationCustomerCapabilities as AccountUpdateParamsConfigurationCustomerCapabilities,
        AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax as AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax,
        AccountUpdateParamsConfigurationCustomerShipping as AccountUpdateParamsConfigurationCustomerShipping,
        AccountUpdateParamsConfigurationCustomerShippingAddress as AccountUpdateParamsConfigurationCustomerShippingAddress,
        AccountUpdateParamsConfigurationMerchant as AccountUpdateParamsConfigurationMerchant,
        AccountUpdateParamsConfigurationMerchantBacsDebitPayments as AccountUpdateParamsConfigurationMerchantBacsDebitPayments,
        AccountUpdateParamsConfigurationMerchantBranding as AccountUpdateParamsConfigurationMerchantBranding,
        AccountUpdateParamsConfigurationMerchantCapabilities as AccountUpdateParamsConfigurationMerchantCapabilities,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments as AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments,
        AccountUpdateParamsConfigurationMerchantCardPayments as AccountUpdateParamsConfigurationMerchantCardPayments,
        AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn as AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn,
        AccountUpdateParamsConfigurationMerchantKonbiniPayments as AccountUpdateParamsConfigurationMerchantKonbiniPayments,
        AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupport as AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupport,
        AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupportHours as AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupportHours,
        AccountUpdateParamsConfigurationMerchantScriptStatementDescriptor as AccountUpdateParamsConfigurationMerchantScriptStatementDescriptor,
        AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKana as AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKana,
        AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKanji as AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKanji,
        AccountUpdateParamsConfigurationMerchantStatementDescriptor as AccountUpdateParamsConfigurationMerchantStatementDescriptor,
        AccountUpdateParamsConfigurationMerchantSupport as AccountUpdateParamsConfigurationMerchantSupport,
        AccountUpdateParamsConfigurationMerchantSupportAddress as AccountUpdateParamsConfigurationMerchantSupportAddress,
        AccountUpdateParamsConfigurationRecipient as AccountUpdateParamsConfigurationRecipient,
        AccountUpdateParamsConfigurationRecipientCapabilities as AccountUpdateParamsConfigurationRecipientCapabilities,
        AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance as AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance,
        AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers as AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers,
        AccountUpdateParamsDefaults as AccountUpdateParamsDefaults,
        AccountUpdateParamsDefaultsProfile as AccountUpdateParamsDefaultsProfile,
        AccountUpdateParamsDefaultsResponsibilities as AccountUpdateParamsDefaultsResponsibilities,
        AccountUpdateParamsIdentity as AccountUpdateParamsIdentity,
        AccountUpdateParamsIdentityAttestations as AccountUpdateParamsIdentityAttestations,
        AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration as AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration,
        AccountUpdateParamsIdentityAttestationsOwnershipDeclaration as AccountUpdateParamsIdentityAttestationsOwnershipDeclaration,
        AccountUpdateParamsIdentityAttestationsPersonsProvided as AccountUpdateParamsIdentityAttestationsPersonsProvided,
        AccountUpdateParamsIdentityAttestationsRepresentativeDeclaration as AccountUpdateParamsIdentityAttestationsRepresentativeDeclaration,
        AccountUpdateParamsIdentityAttestationsTermsOfService as AccountUpdateParamsIdentityAttestationsTermsOfService,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount as AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager as AccountUpdateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceMoneyManager as AccountUpdateParamsIdentityAttestationsTermsOfServiceMoneyManager,
        AccountUpdateParamsIdentityBusinessDetails as AccountUpdateParamsIdentityBusinessDetails,
        AccountUpdateParamsIdentityBusinessDetailsAdditionalAddress as AccountUpdateParamsIdentityBusinessDetailsAdditionalAddress,
        AccountUpdateParamsIdentityBusinessDetailsAddress as AccountUpdateParamsIdentityBusinessDetailsAddress,
        AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue as AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue,
        AccountUpdateParamsIdentityBusinessDetailsDocuments as AccountUpdateParamsIdentityBusinessDetailsDocuments,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner,
        AccountUpdateParamsIdentityBusinessDetailsIdNumber as AccountUpdateParamsIdentityBusinessDetailsIdNumber,
        AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
        AccountUpdateParamsIdentityBusinessDetailsRegistrationDate as AccountUpdateParamsIdentityBusinessDetailsRegistrationDate,
        AccountUpdateParamsIdentityBusinessDetailsScriptAddresses as AccountUpdateParamsIdentityBusinessDetailsScriptAddresses,
        AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana as AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana,
        AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji,
        AccountUpdateParamsIdentityBusinessDetailsScriptNames as AccountUpdateParamsIdentityBusinessDetailsScriptNames,
        AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana as AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana,
        AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji as AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji,
        AccountUpdateParamsIdentityIndividual as AccountUpdateParamsIdentityIndividual,
        AccountUpdateParamsIdentityIndividualAdditionalAddress as AccountUpdateParamsIdentityIndividualAdditionalAddress,
        AccountUpdateParamsIdentityIndividualAdditionalName as AccountUpdateParamsIdentityIndividualAdditionalName,
        AccountUpdateParamsIdentityIndividualAddress as AccountUpdateParamsIdentityIndividualAddress,
        AccountUpdateParamsIdentityIndividualDateOfBirth as AccountUpdateParamsIdentityIndividualDateOfBirth,
        AccountUpdateParamsIdentityIndividualDocuments as AccountUpdateParamsIdentityIndividualDocuments,
        AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization,
        AccountUpdateParamsIdentityIndividualDocumentsPassport as AccountUpdateParamsIdentityIndividualDocumentsPassport,
        AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification as AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification,
        AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
        AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification as AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification,
        AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
        AccountUpdateParamsIdentityIndividualDocumentsVisa as AccountUpdateParamsIdentityIndividualDocumentsVisa,
        AccountUpdateParamsIdentityIndividualIdNumber as AccountUpdateParamsIdentityIndividualIdNumber,
        AccountUpdateParamsIdentityIndividualRelationship as AccountUpdateParamsIdentityIndividualRelationship,
        AccountUpdateParamsIdentityIndividualScriptAddresses as AccountUpdateParamsIdentityIndividualScriptAddresses,
        AccountUpdateParamsIdentityIndividualScriptAddressesKana as AccountUpdateParamsIdentityIndividualScriptAddressesKana,
        AccountUpdateParamsIdentityIndividualScriptAddressesKanji as AccountUpdateParamsIdentityIndividualScriptAddressesKanji,
        AccountUpdateParamsIdentityIndividualScriptNames as AccountUpdateParamsIdentityIndividualScriptNames,
        AccountUpdateParamsIdentityIndividualScriptNamesKana as AccountUpdateParamsIdentityIndividualScriptNamesKana,
        AccountUpdateParamsIdentityIndividualScriptNamesKanji as AccountUpdateParamsIdentityIndividualScriptNamesKanji,
    )
    from stripe.params.v2.core._event_destination_create_params import (
        EventDestinationCreateParams as EventDestinationCreateParams,
        EventDestinationCreateParamsAmazonEventbridge as EventDestinationCreateParamsAmazonEventbridge,
        EventDestinationCreateParamsAzureEventGrid as EventDestinationCreateParamsAzureEventGrid,
        EventDestinationCreateParamsWebhookEndpoint as EventDestinationCreateParamsWebhookEndpoint,
    )
    from stripe.params.v2.core._event_destination_delete_params import (
        EventDestinationDeleteParams as EventDestinationDeleteParams,
    )
    from stripe.params.v2.core._event_destination_disable_params import (
        EventDestinationDisableParams as EventDestinationDisableParams,
    )
    from stripe.params.v2.core._event_destination_enable_params import (
        EventDestinationEnableParams as EventDestinationEnableParams,
    )
    from stripe.params.v2.core._event_destination_list_params import (
        EventDestinationListParams as EventDestinationListParams,
    )
    from stripe.params.v2.core._event_destination_ping_params import (
        EventDestinationPingParams as EventDestinationPingParams,
    )
    from stripe.params.v2.core._event_destination_retrieve_params import (
        EventDestinationRetrieveParams as EventDestinationRetrieveParams,
    )
    from stripe.params.v2.core._event_destination_update_params import (
        EventDestinationUpdateParams as EventDestinationUpdateParams,
        EventDestinationUpdateParamsWebhookEndpoint as EventDestinationUpdateParamsWebhookEndpoint,
    )
    from stripe.params.v2.core._event_list_params import (
        EventListParams as EventListParams,
        EventListParamsCreated as EventListParamsCreated,
    )
    from stripe.params.v2.core._event_retrieve_params import (
        EventRetrieveParams as EventRetrieveParams,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "accounts": ("stripe.params.v2.core.accounts", True),
    "AccountCloseParams": (
        "stripe.params.v2.core._account_close_params",
        False,
    ),
    "AccountCreateParams": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfiguration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomer": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerAutomaticIndirectTax": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBilling": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBillingInvoice": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBillingInvoiceRendering": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerShipping": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerShippingAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchant": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantBacsDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantBranding": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCardPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantKonbiniPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupport": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupportHours": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantScriptStatementDescriptor": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantStatementDescriptor": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantSupport": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantSupportAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipient": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsDefaults": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsDefaultsProfile": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsDefaultsResponsibilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentity": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestations": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsDirectorshipDeclaration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsOwnershipDeclaration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsPersonsProvided": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsRepresentativeDeclaration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfService": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceAccount": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetails": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsAdditionalAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsAnnualRevenue": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocuments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsIdNumber": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsRegistrationDate": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptAddresses": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptNames": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptNamesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividual": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualAdditionalAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualAdditionalName": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDateOfBirth": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocuments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsPassport": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsVisa": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualIdNumber": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualRelationship": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptAddresses": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptAddressesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptAddressesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptNames": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptNamesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptNamesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountLinkCreateParams": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCase": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountOnboarding": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountUpdate": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountListParams": ("stripe.params.v2.core._account_list_params", False),
    "AccountRetrieveParams": (
        "stripe.params.v2.core._account_retrieve_params",
        False,
    ),
    "AccountTokenCreateParams": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentity": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestations": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsDirectorshipDeclaration": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsOwnershipDeclaration": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsPersonsProvided": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsRepresentativeDeclaration": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfService": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceAccount": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetails": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsAdditionalAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsAnnualRevenue": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocuments": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsIdNumber": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsRegistrationDate": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptAddresses": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKana": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKanji": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptNames": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKana": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKanji": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividual": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualAdditionalAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualAdditionalName": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDateOfBirth": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocuments": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsCompanyAuthorization": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsPassport": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsVisa": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualIdNumber": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualRelationship": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptAddresses": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptAddressesKana": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptAddressesKanji": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptNames": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptNamesKana": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptNamesKanji": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenRetrieveParams": (
        "stripe.params.v2.core._account_token_retrieve_params",
        False,
    ),
    "AccountUpdateParams": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfiguration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomer": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBilling": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBillingInvoice": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerShipping": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerShippingAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchant": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantBacsDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantBranding": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCardPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantKonbiniPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupport": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupportHours": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantScriptStatementDescriptor": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantStatementDescriptor": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantSupport": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantSupportAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipient": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsDefaults": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsDefaultsProfile": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsDefaultsResponsibilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentity": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestations": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsOwnershipDeclaration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsPersonsProvided": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsRepresentativeDeclaration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfService": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceMoneyManager": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetails": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsAdditionalAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocuments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsIdNumber": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsRegistrationDate": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptAddresses": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptNames": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividual": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualAdditionalAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualAdditionalName": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDateOfBirth": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocuments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsPassport": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsVisa": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualIdNumber": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualRelationship": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptAddresses": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptAddressesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptAddressesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptNames": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptNamesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptNamesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "EventDestinationCreateParams": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationCreateParamsAmazonEventbridge": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationCreateParamsAzureEventGrid": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationCreateParamsWebhookEndpoint": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationDeleteParams": (
        "stripe.params.v2.core._event_destination_delete_params",
        False,
    ),
    "EventDestinationDisableParams": (
        "stripe.params.v2.core._event_destination_disable_params",
        False,
    ),
    "EventDestinationEnableParams": (
        "stripe.params.v2.core._event_destination_enable_params",
        False,
    ),
    "EventDestinationListParams": (
        "stripe.params.v2.core._event_destination_list_params",
        False,
    ),
    "EventDestinationPingParams": (
        "stripe.params.v2.core._event_destination_ping_params",
        False,
    ),
    "EventDestinationRetrieveParams": (
        "stripe.params.v2.core._event_destination_retrieve_params",
        False,
    ),
    "EventDestinationUpdateParams": (
        "stripe.params.v2.core._event_destination_update_params",
        False,
    ),
    "EventDestinationUpdateParamsWebhookEndpoint": (
        "stripe.params.v2.core._event_destination_update_params",
        False,
    ),
    "EventListParams": ("stripe.params.v2.core._event_list_params", False),
    "EventListParamsCreated": (
        "stripe.params.v2.core._event_list_params",
        False,
    ),
    "EventRetrieveParams": (
        "stripe.params.v2.core._event_retrieve_params",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from decimal import Decimal
from stripe._request_options import RequestOptions
from stripe._stripe_object import UntypedStripeObject
from typing import Dict, List, Union
from typing_extensions import Literal, NotRequired, TypedDict


class PriceCreateParams(RequestOptions):
    active: NotRequired[bool]
    """
    Whether the price can be used for new purchases. Defaults to `true`.
    """
    billing_scheme: NotRequired["Literal['per_unit', 'tiered']|str"]
    """
    Describes how to compute the price per period. Either `per_unit` or `tiered`. `per_unit` indicates that the fixed amount (specified in `unit_amount` or `unit_amount_decimal`) will be charged per unit in `quantity` (for prices with `usage_type=licensed`), or per unit of total usage (for prices with `usage_type=metered`). `tiered` indicates that the unit pricing will be computed using a tiering strategy as defined using the `tiers` and `tiers_mode` attributes.
    """
    currency: str
    """
    Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
    """
    currency_options: NotRequired[
        "Dict[str, PriceCreateParamsCurrencyOptions]|UntypedStripeObject[PriceCreateParamsCurrencyOptions]"
    ]
    """
    Prices defined in each available currency option. Each key must be a three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html) and a [supported currency](https://stripe.com/docs/currencies).
    """
    custom_unit_amount: NotRequired["PriceCreateParamsCustomUnitAmount"]
    """
    When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    lookup_key: NotRequired[str]
    """
    A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.
    """
    metadata: NotRequired["Dict[str, str]|UntypedStripeObject[str]"]
    """
    Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.
    """
    nickname: NotRequired[str]
    """
    A brief description of the price, hidden from customers.
    """
    product: NotRequired[str]
    """
    The ID of the [Product](https://docs.stripe.com/api/products) that this [Price](https://docs.stripe.com/api/prices) will belong to.
    """
    product_data: NotRequired["PriceCreateParamsProductData"]
    """
    These fields can be used to create a new product that this price will belong to.
    """
    recurring: NotRequired["PriceCreateParamsRecurring"]
    """
    The recurring components of a price such as `interval` and `usage_type`.
    """
    tax_behavior: NotRequired[
        "Literal['exclusive', 'inclusive', 'unspecified']|str"
    ]
    """
    Only required if a [default tax behavior](https://docs.stripe.com/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of `inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
    """
    tiers: NotRequired[List["PriceCreateParamsTier"]]
    """
    Each element represents a pricing tier. This parameter requires `billing_scheme` to be set to `tiered`. See also the documentation for `billing_scheme`.
    """
    tiers_mode: NotRequired["Literal['graduated', 'volume']|str"]
    """
    Defines if the tiering price should be `graduated` or `volume` based. In `volume`-based tiering, the maximum quantity within a period determines the per unit price, in `graduated` tiering pricing can successively change as the quantity grows.
    """
    transfer_lookup_key: NotRequired[bool]
    """
    If set to true, will atomically remove the lookup key from the existing price, and assign it to this price.
    """
    transform_quantity: NotRequired["PriceCreateParamsTransformQuantity"]
    """
    Apply a transformation to the reported usage or set quantity before computing the billed price. Cannot be combined with `tiers`.
    """
    unit_amount: NotRequired[int]
    """
    A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge. One of `unit_amount`, `unit_amount_decimal`, or `custom_unit_amount` is required, unless `billing_scheme=tiered`.
    """
    unit_amount_decimal: NotRequired[Decimal]
    """
    Same as `unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
    """


class PriceCreateParamsCurrencyOptions(TypedDict):
    custom_unit_amount: NotRequired[
        "PriceCreateParamsCurrencyOptionsCustomUnitAmount"
    ]
    """
    When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.
    """
    tax_behavior: NotRequired[
        "Literal['exclusive', 'inclusive', 'unspecified']|str"
    ]
    """
    Only required if a [default tax behavior](https://docs.stripe.com/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of `inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
    """
    tiers: NotRequired[List["PriceCreateParamsCurrencyOptionsTier"]]
    """
    Each element represents a pricing tier. This parameter requires `billing_scheme` to be set to `tiered`. See also the documentation for `billing_scheme`.
    """
    unit_amount: NotRequired[int]
    """
    A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
    """
    unit_amount_decimal: NotRequired[Decimal]
    """
    Same as `unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
    """


class PriceCreateParamsCurrencyOptionsCustomUnitAmount(TypedDict):
    enabled: bool
    """
    Pass in `true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
    """
    maximum: NotRequired[int]
    """
    The maximum unit amount the customer can specify for this item.
    """
    minimum: NotRequired[int]
    """
    The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.
    """
    preset: NotRequired[int]
    """
    The starting unit amount which can be updated by the customer.
    """


class PriceCreateParamsCurrencyOptionsTier(TypedDict):
    flat_amount: NotRequired[int]
    """
    The flat billing amount for an entire tier, regardless of the number of units in the tier.
    """
    flat_amount_decimal: NotRequired[Decimal]
    """
    Same as `flat_amount`, but accepts a decimal value representing an integer in the minor units of the currency. Only one of `flat_amount` and `flat_amount_decimal` can be set.
    """
    unit_amount: NotRequired[int]
    """
    The per unit billing amount for each individual unit for which this tier applies.
    """
    unit_amount_decimal: NotRequired[Decimal]
    """
    Same as `unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
    """
    up_to: Union[Literal["inf"], int]
    """
    Specifies the upper bound of this tier. The lower bound of a tier is the upper bound of the previous tier adding one. Use `inf` to define a fallback tier.
    """


class PriceCreateParamsCustomUnitAmount(TypedDict):
    enabled: bool
    """
    Pass in `true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
    """
    maximum: NotRequired[int]
    """
    The maximum unit amount the customer can specify for this item.
    """
    minimum: NotRequired[int]
    """
    The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.
    """
    preset: NotRequired[int]
    """
    The starting unit amount which can be updated by the customer.
    """


class PriceCreateParamsProductData(TypedDict):
    active: NotRequired[bool]
    """
    Whether the product is currently available for purchase. Defaults to `true`.
    """
    id: NotRequired[str]
    """
    The identifier for the product. Must be unique. If not provided, an identifier will be randomly generated.
    """
    metadata: NotRequired["Dict[str, str]|UntypedStripeObject[str]"]
    """
    Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.
    """
    name: str
    """
    The product's name, meant to be displayable to the customer.
    """
    statement_descriptor: NotRequired[str]
    """
    An arbitrary string to be displayed on your customer's credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.

    This may be up to 22 characters. The statement description may not include `<`, `>`, `\\`, `"`, `'` characters, and will appear on your customer's statement in capital letters. Non-ASCII characters are automatically stripped.
    """
    tax_code: NotRequired[str]
    """
    A [tax code](https://docs.stripe.com/tax/tax-categories) ID.
    """
    unit_label: NotRequired[str]
    """
    A label that represents units of this product. When set, this will be included in customers' receipts, invoices, Checkout, and the customer portal.
    """


class PriceCreateParamsRecurring(TypedDict):
    interval: Union[Literal["day", "month", "week", "year"], str]
    """
    Specifies billing frequency. Either `day`, `week`, `month` or `year`.
    """
    interval_count: NotRequired[int]
    """
    The number of intervals between subscription billings. For example, `interval=month` and `interval_count=3` bills every 3 months. Maximum of three years interval allowed (3 years, 36 months, or 156 weeks).
    """
    meter: NotRequired[str]
    """
    The meter tracking the usage of a metered price
    """
    trial_period_days: NotRequired[int]
    """
    Default number of trial days when subscribing a customer to this price using [`trial_from_plan=true`](https://docs.stripe.com/api#create_subscription-trial_from_plan).
    """
    usage_type: NotRequired["Literal['licensed', 'metered']|str"]
    """
    Configures how the quantity per period should be determined. Can be either `metered` or `licensed`. `licensed` automatically bills the `quantity` set when adding it to a subscription. `metered` aggregates the total usage based on usage records. Defaults to `licensed`.
    """


class PriceCreateParamsTier(TypedDict):
    flat_amount: NotRequired[int]
    """
    The flat billing amount for an entire tier, regardless of the number of units in the tier.
    """
    flat_amount_decimal: NotRequired[Decimal]
    """
    Same as `flat_amount`, but accepts a decimal value representing an integer in the minor units of the currency. Only one of `flat_amount` and `flat_amount_decimal` can be set.
    """
    unit_amount: NotRequired[int]
    """
    The per unit billing amount for each individual unit for which this tier applies.
    """
    unit_amount_decimal: NotRequired[Decimal]
    """
    Same as `unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
    """
    up_to: Union[Literal["inf"], int]
    """
    Specifies the upper bound of this tier. The lower bound of a tier is the upper bound of the previous tier adding one. Use `inf` to define a fallback tier.
    """


class PriceCreateParamsTransformQuantity(TypedDict):
    divide_by: int
    """
    Divide usage by this number.
    """
    round: Union[Literal["down", "up"], str]
    """
    After division, either round the result `up` or `down`.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._list_object import ListObject
    from stripe._payment_intent_amount_details_line_item import (
        PaymentIntentAmountDetailsLineItem,
    )
    from stripe._request_options import RequestOptions
    from stripe.params._payment_intent_amount_details_line_item_list_params import (
        PaymentIntentAmountDetailsLineItemListParams,
    )


class PaymentIntentAmountDetailsLineItemService(StripeService):
    def list(
        self,
        intent: str,
        params: Optional[
            "PaymentIntentAmountDetailsLineItemListParams"
        ] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[PaymentIntentAmountDetailsLineItem]":
        """
        Lists all LineItems of a given PaymentIntent.
        """
        return cast(
            "ListObject[PaymentIntentAmountDetailsLineItem]",
            self._request(
                "get",
                "/v1/payment_intents/{intent}/amount_details_line_items".format(
                    intent=sanitize_id(intent),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        intent: str,
        params: Optional[
            "PaymentIntentAmountDetailsLineItemListParams"
        ] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[PaymentIntentAmountDetailsLineItem]":
        """
        Lists all LineItems of a given PaymentIntent.
        """
        return cast(
            "ListObject[PaymentIntentAmountDetailsLineItem]",
            await self._request_async(
                "get",
                "/v1/payment_intents/{intent}/amount_details_line_items".format(
                    intent=sanitize_id(intent),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )
